pychemia.external package
=========================

.. automodule:: pychemia.external
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    pychemia.external.ase
    pychemia.external.findsym
    pychemia.external.pymatgen
    pychemia.external.symmol

